"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from openrouter.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ToolDefinitionJSONFunctionTypedDict(TypedDict):
    name: str
    description: NotRequired[str]
    parameters: NotRequired[Dict[str, Any]]
    strict: NotRequired[Nullable[bool]]


class ToolDefinitionJSONFunction(BaseModel):
    name: str

    description: Optional[str] = None

    parameters: Optional[Dict[str, Any]] = None

    strict: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["description", "parameters", "strict"]
        nullable_fields = ["strict"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ToolDefinitionJSONTypedDict(TypedDict):
    function: ToolDefinitionJSONFunctionTypedDict
    type: Literal["function"]


class ToolDefinitionJSON(BaseModel):
    function: ToolDefinitionJSONFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openresponsesnonstreamingresponse import (
    OpenResponsesNonStreamingResponse,
    OpenResponsesNonStreamingResponseTypedDict,
)
from .openresponsesstreamevent import (
    OpenResponsesStreamEvent,
    OpenResponsesStreamEventTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import eventstreaming
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


class CreateResponsesResponseBodyTypedDict(TypedDict):
    r"""Successful response"""

    data: OpenResponsesStreamEventTypedDict
    r"""Union of all possible event types emitted during response streaming"""


class CreateResponsesResponseBody(BaseModel):
    r"""Successful response"""

    data: OpenResponsesStreamEvent
    r"""Union of all possible event types emitted during response streaming"""


CreateResponsesResponseTypedDict = TypeAliasType(
    "CreateResponsesResponseTypedDict",
    Union[
        OpenResponsesNonStreamingResponseTypedDict,
        Union[
            eventstreaming.EventStream[OpenResponsesStreamEventTypedDict],
            eventstreaming.EventStreamAsync[OpenResponsesStreamEventTypedDict],
        ],
    ],
)


CreateResponsesResponse = TypeAliasType(
    "CreateResponsesResponse",
    Union[
        OpenResponsesNonStreamingResponse,
        Union[
            eventstreaming.EventStream[OpenResponsesStreamEvent],
            eventstreaming.EventStreamAsync[OpenResponsesStreamEvent],
        ],
    ],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatresponse import ChatResponse, ChatResponseTypedDict
from .chatstreamingresponsechunk import (
    ChatStreamingResponseChunkData,
    ChatStreamingResponseChunkDataTypedDict,
)
from openrouter.utils import eventstreaming
from typing import Union
from typing_extensions import TypeAliasType


SendChatCompletionRequestResponseTypedDict = TypeAliasType(
    "SendChatCompletionRequestResponseTypedDict",
    Union[
        ChatResponseTypedDict,
        Union[
            eventstreaming.EventStream[ChatStreamingResponseChunkDataTypedDict],
            eventstreaming.EventStreamAsync[ChatStreamingResponseChunkDataTypedDict],
        ],
    ],
)


SendChatCompletionRequestResponse = TypeAliasType(
    "SendChatCompletionRequestResponse",
    Union[
        ChatResponse,
        Union[
            eventstreaming.EventStream[ChatStreamingResponseChunkData],
            eventstreaming.EventStreamAsync[ChatStreamingResponseChunkData],
        ],
    ],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitem import (
    ChatMessageContentItem,
    ChatMessageContentItemTypedDict,
)
from .chatmessagetoolcall import ChatMessageToolCall, ChatMessageToolCallTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from openrouter.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


AssistantMessageContentTypedDict = TypeAliasType(
    "AssistantMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTypedDict]],
)


AssistantMessageContent = TypeAliasType(
    "AssistantMessageContent", Union[str, List[ChatMessageContentItem]]
)


class AssistantMessageTypedDict(TypedDict):
    role: Literal["assistant"]
    content: NotRequired[Nullable[AssistantMessageContentTypedDict]]
    name: NotRequired[str]
    tool_calls: NotRequired[List[ChatMessageToolCallTypedDict]]
    refusal: NotRequired[Nullable[str]]
    reasoning: NotRequired[Nullable[str]]


class AssistantMessage(BaseModel):
    ROLE: Annotated[
        Annotated[Literal["assistant"], AfterValidator(validate_const("assistant"))],
        pydantic.Field(alias="role"),
    ] = "assistant"

    content: OptionalNullable[AssistantMessageContent] = UNSET

    name: Optional[str] = None

    tool_calls: Optional[List[ChatMessageToolCall]] = None

    refusal: OptionalNullable[str] = UNSET

    reasoning: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["content", "name", "tool_calls", "refusal", "reasoning"]
        nullable_fields = ["content", "refusal", "reasoning"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .publicendpoint import PublicEndpoint, PublicEndpointTypedDict
from openrouter.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListEndpointsZdrResponseTypedDict(TypedDict):
    r"""Returns a list of endpoints"""

    data: List[PublicEndpointTypedDict]


class ListEndpointsZdrResponse(BaseModel):
    r"""Returns a list of endpoints"""

    data: List[PublicEndpoint]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


OpenAIResponsesTruncation = Union[
    Literal[
        "auto",
        "disabled",
    ],
    UnrecognizedStr,
]
